# IBLM:Inductive Bias Learning Models


- [](#)
- [How It Works](#how-it-works)
- [How to Use](#how-to-use)
- [Supported Models](#supported-models)
- [Contributor](#contributor)
- [Backstory](#backstory)



## What is IBLM?



## How It Works





## How to Use
Use the link below to try it out immediately on Google colab.


## Supported Models
Currently, the recommended model is GPT-4


## Contributor
- [@t-ymbys](https://github.com/t-ymbys)
- [@cn47](https://github.com/cn47)


## Backstory
This idea is based on [langchain-tools](https://github.com/fuyu-quant/langchain-tools), which was created in an attempt to make LLM learn LightGBM.